# morsecco
Morsecco is a minimalistic, but mighty programming language using the morse
code for coding.  If you know the morse code, a little forth and are a type
safety anarchist, you are almost done. Otherwise read the tutorial.

Currently, morsecco is work in progress. Neither the language is finally
defined nor the interpreter is bug-free. But it is already usable: You can
follow the tutorial and write code.

Contributions like bug report, pull requests and feedback are highly welcome.
Before submitting commits, please ensure the tests.sh script still passes all
tests. The test coverage is still poor so feels yourself invited to add tests.
